@@ -33,15 +33,7 @@ my $schema = {
             required => 1,
             mapping  => {
                 lines          => { type => 'int', },
-                address        => { type => 'str', },
-                port           => { type => 'int', required => 1, },
-                title          => { type => 'str', },
-                content_type   => { type => 'str', },
-                charset        => { type => 'str', },
-                host           => { type => 'str', },
                 root           => { type => 'str', },
-                echo           => { type => 'bool', },
-                recent_log_per_page => { type => 'int', },
             },
         },
         global => {
@@ -95,9 +87,8 @@ sub load {
     }
 
     # set default vars.
+    $config->{httpd}->{lines}          ||= 20;
     $config->{httpd}->{root}           ||= decode( 'utf8', '/' );
-    $config->{httpd}->{echo} = true unless exists $config->{httpd}->{echo};
-    $config->{httpd}->{recent_log_per_page} ||= 30;
     $config->{global}->{assets_dir}    ||= File::Spec->catfile( $FindBin::Bin, 'assets' );
 
     return $config;
